@@ -1,6 +1,6 @@
 ## high-level convenience interface
-raschtree <- function(formula, data, minsplit = 10, gradtol = 1e-6,
-  deriv = c("sum", "diff", "numeric"), ...)
+raschtree <- function(formula, data, minsplit = 10, reltol = 1e-10,
+  deriv = c("sum", "diff", "numeric"), hessian = TRUE, maxit = 100L, ...)
 {
   ## transform formula
   stopifnot(length(formula) > 2)
@@ -10,7 +10,7 @@ raschtree <- function(formula, data, minsplit = 10, gradtol = 1e-6,
   ff[[3]][[3]] <- formula[[3]]
 
   ## formula/data/model pre-processing
-  raschmod <- RaschModel(gradtol = gradtol, deriv = deriv)
+  raschmod <- RaschModel(reltol = reltol, deriv = deriv, hessian = hessian, maxit = maxit)
   ff <- attr(ParseFormula(ff), "formula")
   ff$input[[3]] <- ff$input[[2]]
   ff$input[[2]] <- ff$response[[2]]
@@ -65,6 +65,29 @@ coef.raschtree <- function (object, node = NULL, ...)
   return(rval)
 }
 
+
+itempar.raschtree <- function (object, node = NULL, ...) {
+
+  object <- object$mob
+  if(is.null(node)) node <- terminal_nodeIDs(object@tree)
+  rval <- lapply(nodes(object, node), function(z) itempar.RaschModel(z$model, ...))
+  names(rval) <- node
+
+  return(rval)
+
+}
+
+threshold.raschtree <- function (object, node = NULL, ...) {
+
+  object <- object$mob
+  if(is.null(node)) node <- terminal_nodeIDs(object@tree)
+  rval <- lapply(nodes(object, node), function(z) threshold.RaschModel(z$model, ...))
+  names(rval) <- node
+
+  return(rval)
+
+}
+
 worth.raschtree <- function (object, node = NULL, ...) 
 {
   object <- object$mob
